//---------------------------------------------------------------------------
//    $Id: mesh_worker_vector_selector.cc 24247 2011-09-04 17:20:00Z young $
//    Version: $Name$
//
//    Copyright (C) 2009, 2010 by the deal.II authors
//
//    This file is subject to QPL and may not be  distributed
//    without copyright and license information. Please refer
//    to the file deal.II/doc/license.html for the  text  and
//    further information on this license.
//
//---------------------------------------------------------------------------

#include <deal.II/lac/vector.h>
#include <deal.II/lac/block_vector.h>
#include <deal.II/lac/petsc_vector.h>
#include <deal.II/lac/petsc_block_vector.h>
#include <deal.II/lac/trilinos_vector.h>
#include <deal.II/lac/trilinos_block_vector.h>

#include <deal.II/meshworker/vector_selector.templates.h>

DEAL_II_NAMESPACE_OPEN

#include "mesh_worker_vector_selector.inst"


DEAL_II_NAMESPACE_CLOSE
